@@ -39,11 +39,9 @@ class ApplyUpgrade:
         stdout = ""
         while p.poll() is None:
             # send alive ping
-            if getattr(config, "machine_readable", False):
-                # ensure its written out
-                sys.stdout.write(json.dumps({"type": "spinner",
-                                             "msg": "Applying update"})+"\n")
-                sys.stdout.flush()
+            sys.stdout.write(json.dumps({"type": "spinner",
+                                         "msg": "Applying update"})+"\n")
+            sys.stdout.flush()
             if select.select([p.stdout.fileno()], [], [], 0.1) != ([], [], []):
                 stdout += p.stdout.read(1).decode("utf-8", errors="replace")
         # get return code
